# Script 1. Calculation of decomposability scores

Jacolien van Rij, May 2019

Supplementary materials for the paper: Simone A. Sprenger, Amélie la Roi, and Jacolien van Rij, The Development of Idiom Knowledge across the Life Span. May 2019. Under review.


---

## Packages and data

```r
library(plyr) 
library(itsadug)
library(mgcv)
library(plotfunctions)
```

The decomposability ratings are available for download [here](./Data).

```r
load("Data/Decomposability.rda")
```

---
## Calculate mean decomposability scores per idiom

```r
# calculate averages:
ratings <- ddply(dat, c("Item", "Description", "Type", "Freq", "LogFreq"), 
                 summarise,
                 mean.item   = mean(Score, na.rm=TRUE),
                 median.item = median(Score, na.rm=TRUE),
                 n.all       = length(Score),
                 n.rating    = length(Score[!is.na(Score)]),
                 n.unfamiliar= length(Score[is.na(Score)])
                 )

ratings <- ratings[order(ratings$Item),]
row.names(ratings) <- NULL
```

---
## Estimated decomposability ratings using partial pooling

```r
# strings as factors:
dat$Item <- as.factor(dat$Item)
dat$Subject <- as.factor(dat$Subject)

# select only familiar items (no NAs):
dat2 <- droplevels(dat[!is.na(dat$Score),])

# Fitting ocat GAMM:
# (may take a while to run)
runthis <- FALSE
if(runthis){
  m1 <- bam(Score ~ s(Item, bs='re') + s(Subject, bs='re'),
              data=dat2, family=ocat(R=5), method="ML")
  save(m1, file="m1-decomp.rda", compress="xz")
}else{
  load("m1-decomp.rda")
}

# add arbitrary subject for extracting predictions:
ratings$Subject <- dat$Subject[1]

# get predictions on response scale 
# (i.e., probability for each category):
fv <- predict(m1, droplevels(ratings[ratings$n.rating > 0,]), 
              exclude="s(Subject)", type="response")
fit <- apply(fv, 1, function(x){return( x[1]+x[2]*2+x[3]*3+x[4]*4+x[5]*5 )})
# add to ratings:
ratings$est <- NA
ratings[ratings$n.rating > 0,]$est <- fit

# get predictions on link scale:
fv <- predict(m1, droplevels(ratings[ratings$n.rating > 0,]), 
              exclude="s(Subject)", type="link")
ratings$est.link <- NA
ratings[ratings$n.rating > 0,]$est.link <- fv

# save ratings:
ratings$Subject <- NULL
save(ratings, file="ratings.rda", compress="xz")
```

